# Welcome to the wBuild demo project!

wBuild is all about making your day easier resolving, updating and cascading various dependencies, pipeline rules and
code structs. Why bother clicking various files and directories in your project one-by-one? Instead of that, wBuild lets you
specify all the needed information in a YAML header right in your code and let the automated Snakemake processes do the rest!

This is a demonstration of the features wBuild provides. By default there are various scripts and markdown files from a 
project rendered 
to this HTML output where you can learn more about features and workflow of wBuild - they are available at the most right
tab in the header.
