#'---
#' title: Report 1
#' author: Leonhard Wachutka
#' wb:
#'  input:
#'  output:
#' output:
#'  knitrBootstrap::bootstrap_document
#'---

#' #KnitrBootsrap Theme
#' This is tutorial text
#' 
#' 
#' #Next topic
#' 
#' ##Sub Header

plot(1:10,1:10)
#' ##Sub Header2
plot(1:100,1:100)

#' ##Sub Header3
plot(1:10,1:10)

#' #Tutorial 2
#' This is tutorial text
#' 
#' 
#' #Next topic
#' 
#' ##Sub Header
plot(1:10,1:10)
