#'---
#' title: SubTask report
#' author: Leonhard Wachutka
#' wb:
#'  input: ['Data/data.RDS']
#'---

#' #Tutorial
#' This is tutorial text
#' 
#' 
#' #Next topic
#' 
#' ##Sub Header
readRDS("Data/data.RDS")
plot(1:10,1:10)
#' ##Sub Header2
plot(1:10,1:10)

#' ##Sub Header3
plot(1:10,1:10)

#' #Tutorial 2
#' This is tutorial text
#' 
#' 
#' #Next topic
#' 
#' ##Sub Header
plot(1:10,2:11)


